@@ -1,5 +1,5 @@
 brownian.bridge <-
-function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.step=10){
+function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.step=10, max.lag=NULL){
 
     # Input: 
     #   x, y = Vectors of coordinates of ordered animal locations, in UTMs.
@@ -17,6 +17,7 @@ function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.st
 	#			discretizing time into arbitrarily small intervals of time.step. The default 
 	#			is 10 units (same as time.lag). Longer time.step speeds up estimation, 
 	#			but reduces precision.
+	#	max.lag = maximum lag between successful locations to consider in the analysis
     # Output: 
     #   UD = List with estimated Brownian.Motion.Variance, "x", "y", and "z", 
     #       where x and y are grid center point coordinates and z is the estimated
@@ -43,14 +44,16 @@ function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.st
         y. <- seq(min.grid.y, max.grid.y, cell.size)
         area.grid <- merge(x., y.)
     }
-    
+	if(is.null(max.lag)){
+		max.lag = max(time.lag)+1
+	}    
     if(length(location.error) == 1){
         location.error <- rep(location.error, length(x))
     }
     
     n.locs <- length(x)
 
-    BMvar <- brownian.motion.variance(n.locs, time.lag, location.error, x, y)
+    BMvar <- brownian.motion.variance(n.locs, time.lag, location.error, x, y, max.lag)
     BMvar <- rep(BMvar, times=length(x))
 
     # Use 10 units (generally minutes) as default.
@@ -64,27 +67,31 @@ function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.st
     names(bbmm) <- c("Brownian motion variance", "x", "y", "probability")
     class(bbmm) <- "bbmm"
     
-    #dyn.load("BBMM.dll")	# comment out before package creation
-
-    ans <- .Fortran("BBMM",
-                    as.integer(n.locs), 
-                    as.integer(grid.size), 
-                    as.double(time.lag), 
-                    as.double(T.Total), 
-                    as.double(x), 
-                    as.double(y), 
-                    as.double(BMvar), 
-                    as.double(location.error), 
-                    as.double(area.grid[,1]), 
-                    as.double(area.grid[,2]), 
-                    as.double(time.step), 
-                    as.double(probability),
-                    PACKAGE="BBMM")
+	probability <- NULL
+	int <- 0
+	for(i in 1:(n.locs-1)){
+		if(time.lag[i] <= max.lag){
+			theta <- NULL
+			tm <- 0
+			while(tm <= time.lag[i]){
+				alpha <- tm/time.lag[i]
+				mu.x <- x[i] + alpha*(x[i+1] - x[i])
+				mu.y <- y[i] + alpha*(y[i+1] - y[i])
+				sigma.2 <- time.lag[i]*alpha*(1-alpha)*BMvar[i] + 
+					((1-alpha)^2)*(location.error[i]^2) + 
+					(alpha^2)*(location.error[i+1]^2)
+				ZTZ <- (area.grid[,1] - mu.x)^2 + (area.grid[,2] - mu.y)^2
+				theta <- (1/sqrt(2*pi*sigma.2))*exp(-ZTZ/(2*sigma.2)) 
+				int <- int + theta
+				tm <- tm + time.step
+			}
+		}
+	}
+	#Scaling probabilities so they sum to 1.0
+	probability <- int/T.Total
+	probability <- probability/sum(probability)
     
-    bbmm[[4]] <- ans[[12]]    
-
-    #dyn.unload("BBMM.dll")		# comment out before package creation
-
+    bbmm[[4]] <- probability   
     bbmm[[1]] <- BMvar[1]
     bbmm[[2]] <- area.grid[,1]
     bbmm[[3]] <- area.grid[,2]
@@ -92,4 +99,3 @@ function(x, y, time.lag, location.error, area.grid=NULL, cell.size=NULL, time.st
     return(bbmm)
 
 }
-
